@@ -116,7 +116,10 @@ class MDS:
         name = info["name"]
         data_type = info["data_type"]
         space = info["project"]
-        tags = info["tag_names"]
+        if "tag_names" in info:
+            tags = info["tag_names"]
+        else:
+            tags = []
         created_user = info["created_user"]
         create_timestamp = info["create_timestamp"]
         versions = info["versions"]
@@ -280,6 +283,7 @@ class MDS:
             CloudClient.upload_files_parallel(identifier, bucket, file_path, upload_prefix, 1, 8)
         else:
             CloudClient.upload_file(identifier, bucket, file_path, upload_prefix)
+        return f'/{bucket}/{upload_prefix}'
 
     def download_files_from_s3_storage(
             self,
@@ -351,16 +355,15 @@ class MDS:
         if len(pre_annotated_dataset) > 0:
             dataset = self.get_dataset_by_id(pre_annotated_dataset[0])
             dataset.export_data(file_path, storage_type, dataset_ids=pre_annotated_dataset)
+
+        if len(annotated_dataset) > 0:
             json_file = os.path.join(file_path, 'output.json')
             if os.path.exists(json_file):
                 os.rename(json_file, os.path.join(file_path, 'output.json.pre'))
-
-        if len(annotated_dataset) > 0:
             dataset = self.get_dataset_by_id(annotated_dataset[0])
             dataset.export_data(file_path, storage_type, dataset_ids=annotated_dataset)
             pre_json_file = os.path.join(file_path, 'output.json.pre')
             if os.path.exists(pre_json_file):
-                json_file = os.path.join(file_path, 'output.json')
                 file_out = open(json_file, 'a')
                 with open(pre_json_file, 'r') as file_in:
                     for line in file_in.readlines():
