@@ -418,13 +418,13 @@ class Dataset(DatasetMeta):
                 raise InvalidParamsError(message=f"export_path value type should be list")
 
         if not dataset_ids:
-            self._x_api.post_export(self._id, post_data)
+            task_id = self._x_api.post_export(self._id, post_data)
         else:
-            self._x_api.post_export_multi(self._id, post_data)
+            task_id = self._x_api.post_export_multi(self._id, post_data)
         print("export data start, please wait...")
 
         with tqdm(total=100) as pbar:
-            download_url = self._validate_export(pbar)
+            download_url = self._validate_export(task_id, pbar=pbar)
 
         catalog = self._x_api.get_export_catalog(download_url)
 
@@ -492,12 +492,13 @@ class Dataset(DatasetMeta):
 
     def _validate_export(
             self,
+            task_id: str,
             pbar: Optional[tqdm] = None
     ) -> str:
         last_progress = 0
         time.sleep(0.3)
         while True:
-            info = self._x_api.get_export_status(self._id)
+            info = self._x_api.get_export_status(self._id, task_id)
             progress = info["progress"]
             if progress == -1:
                 raise InternalServerError(message=info["message"])
